#
# spec file for package python-opentelemetry-sdk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-sdk
Version:        1.24.0
Release:        1.1
Summary:        OpenTelemetry Python SDK
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-sdk/opentelemetry_sdk-%{version}.tar.gz
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module opentelemetry-api == %{version}}
BuildRequires:  %{python_module opentelemetry-semantic-conventions == 0.44b0}
BuildRequires:  %{python_module opentelemetry-test-utils == 0.44b0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing-extensions >= 3.7.4}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-opentelemetry-api == %{version}
Requires:       python-opentelemetry-semantic-conventions == 0.44b0
Requires:       python-typing-extensions >= 3.7.4
BuildArch:      noarch
%python_subpackages

%description
OpenTelemetry Python SDK for the OpenTelemetry Project <https://opentelemetry.io/>

%prep
%autosetup -p1 -n opentelemetry_sdk-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -rvf tests/performance tests/trace/test_trace.py
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/opentelemetry/sdk
%{python_sitelib}/opentelemetry_sdk-%{version}.dist-info

%changelog
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Make create_gauge non-abstract method
  * Make `tracer.start_as_current_span()` decorator work with
    async functions
  * Fix python 3.12 deprecation warning
  * bump mypy to 0.982
  * Add support for OTEL_SDK_DISABLED environment variable
  * Fix ValueError message for PeriodicExportingMetricsReader
  * Use `BaseException` instead of `Exception` in
    `record_exception`
  * Make span.record_exception more robust
  * Fix license field in pyproject.toml files
* Tue Mar 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing python-wheel build dependency to BuildRequires
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 1.23.0:
  * Use Attribute rather than boundattribute in logrecord (#3567)
  * Fix flush error when no LoggerProvider configured for LoggingHandler (#3608)
  * Fix OTLPMetricExporter ignores preferred_aggregation property (#3603)
  * Logs: set observed_timestamp field (#3565)
  * Add missing Resource SchemaURL in OTLP exporters (#3652)
  * Fix loglevel warning text (#3566)
  * Prometheus Exporter string representation for target_info labels (#3659)
  * Logs: ObservedTimestamp field is missing in console exporter output (#3564)
  * Fix explicit bucket histogram aggregation (#3429)
  * Add code.lineno, code.function and code.filepath to all logs (#3645)
  * Add Synchronous Gauge instrument (#3462)
  * Drop support for 3.7 (#3668)
  * Include key in attribute sequence warning (#3639)
  * Upgrade markupsafe, Flask and related dependencies to dev and test
    environments (#3609)
  * Handle HTTP 2XX responses as successful in OTLP exporters (#3623)
  * Improve Resource Detector timeout messaging (#3645)
  * Add Proxy classes for logging (#3575)
  * Remove dependency on 'backoff' library (#3679)
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 1.23.0:
  * Use Attribute rather than boundattribute in logrecord (#3567)
  * Fix flush error when no LoggerProvider configured for LoggingHandler (#3608)
  * Fix OTLPMetricExporter ignores preferred_aggregation property (#3603)
  * Logs: set observed_timestamp field (#3565)
  * Add missing Resource SchemaURL in OTLP exporters (#3652)
  * Fix loglevel warning text (#3566)
  * Prometheus Exporter string representation for target_info labels (#3659)
  * Logs: ObservedTimestamp field is missing in console exporter output (#3564)
  * Fix explicit bucket histogram aggregation (#3429)
  * Add code.lineno, code.function and code.filepath to all logs (#3645)
  * Add Synchronous Gauge instrument (#3462)
  * Drop support for 3.7 (#3668)
  * Include key in attribute sequence warning (#3639)
  * Upgrade markupsafe, Flask and related dependencies to dev and test
    environments (#3609)
  * Handle HTTP 2XX responses as successful in OTLP exporters (#3623)
  * Improve Resource Detector timeout messaging (#3645)
  * Add Proxy classes for logging (#3575)
  * Remove dependency on 'backoff' library (#3679)
* Thu Mar  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Add %%{?sle15_python_module_pythons}
* Thu Jan  4 2024 Dirk Müller <dmueller@suse.com>
- Initial package (1.22.0)
